@@ -41,6 +41,7 @@ class Subject(EntityType):
                         vocabulary=('right', 'left', 'ambidextrous', 'mixed', 'unknown'))
     related_studies = SubjectRelation('Study', cardinality='**')
     related_groups = SubjectRelation('SubjectGroup', cardinality='**')
+    related_infos = SubjectRelation('ScoreValue', cardinality='**')
     related_diseases = SubjectRelation('Disease', cardinality='**')
     related_lesions = SubjectRelation('BodyLocation', cardinality='**')
     related_diagnostics = SubjectRelation('Diagnostic', cardinality='**', composite='subject')
@@ -129,7 +130,7 @@ class Protocol(EntityType):
     """ A protocol for a study or a measure """
     identifier = String(required=True, unique=True, indexed=True, maxsize=64)
     name = String(internationalizable=True)
-    related_study = SubjectRelation('Study', cardinality='1*', inlined=True, composite='object')
+    related_study = SubjectRelation('Study', cardinality='?*', inlined=True, composite='object')
     start_datetime = Date()
     end_datetime = Date()
     configuration_files = SubjectRelation(('File', 'FileSet', 'ExternalFile'),
@@ -214,7 +215,7 @@ class DrugTake(EntityType):
     stop_taking_date = Date()
     # Order for multiple drugs if it is relevant
     take_order = Int()
-    dosis = Int()
+    dosis = Float()
     unit = Int()#quantity = dosis * unit
     number_of_cycles = Int()
     dosis_percentage = Float(description=u'dosis percentage, w.r.t. the expansion cohort')
